@@ -1,6 +1,6 @@
 package YAML::Any;
 
-our $VERSION = '0.84';
+our $VERSION = '0.85';
 
 use strict;
 use Exporter ();
@@ -118,6 +118,10 @@ sub croak {
 
 1;
 
+__END__
+
+=encoding UTF-8
+
 =head1 NAME
 
 YAML::Any - Pick a YAML implementation and use it.
